@@ -17,7 +17,7 @@ from dbt.contracts.graph.manifest import Manifest
 from dbt.contracts.results import RunResult
 from dbt.exceptions import InternalException
 from dbt.graph import Graph
-from dbt.main import adapter_management, initialize_config_values, track_run
+from dbt.main import adapter_management, read_user_config, track_run
 from dbt.task.base import BaseTask
 from dbt.task.build import BuildTask
 from dbt.task.clean import CleanTask
@@ -33,14 +33,10 @@ from dbt.task.runnable import ManifestTask
 from dbt.task.seed import SeedTask
 from dbt.task.snapshot import SnapshotTask
 from dbt.task.test import TestTask
-from dbt.version import get_installed_version
+from dbt.tracking import initialize_from_flags
 
 from airflow.hooks.base_hook import BaseHook
 
-DBT_VERSION = get_installed_version()
-DBT_VERSION_STRING = DBT_VERSION.to_version_string()
-DBT_VERSION_TUPLE = (int(DBT_VERSION.major), int(DBT_VERSION.minor))
-
 
 class FromStrMixin(Enum):
     """Access enum variants with strings ensuring uppercase."""
@@ -59,13 +55,6 @@ class LogFormat(FromStrMixin, Enum):
     TEXT = "text"
 
 
-class IndirectSelection(FromStrMixin, Enum):
-    """Allowed indirect selection arguments."""
-
-    EAGER = "eager"
-    CAUTIOS = "cautios"
-
-
 class Output(FromStrMixin, Enum):
     """Allowed output arguments."""
 
@@ -85,37 +74,82 @@ class Output(FromStrMixin, Enum):
 class BaseConfig:
     """BaseConfig dbt arguments for all tasks."""
 
-    record_timing_info: Optional[str] = None
-    debug: Optional[bool] = None
-    bypass_cache: Optional[bool] = None
-    log_format: Optional[LogFormat] = None
-    warn_error: Optional[bool] = None
-    use_experimental_parser: Optional[bool] = None
-    no_static_parser: Optional[bool] = None
-    no_anonymous_usage_stats: Optional[bool] = None
-    partial_parse: Optional[bool] = None
-    no_partial_parse: Optional[bool] = None
-    use_colors: Optional[bool] = None
-    no_use_colors: Optional[bool] = None
-    no_version_check: Optional[bool] = None
-    single_threaded: Optional[bool] = None
-    fail_fast: Optional[bool] = None
+    cls: BaseTask = dataclasses.field(default=BaseTask, init=False, repr=False)
+
+    # dbt project configuration
     project_dir: Optional[str] = None
     profiles_dir: Optional[str] = None
     profile: Optional[str] = None
     target: Optional[str] = None
-    vars: str = "{}"
-    log_cache_events: Optional[bool] = None
-    defer: Optional[bool] = None
-    no_defer: Optional[bool] = None
-    state: Optional[str] = None
-    threads: Optional[int] = None
+
+    # Execution configuration
     compiled_target: Optional[Union["os.PathLike[str]", str]] = None
+    fail_fast: Optional[bool] = None
+    single_threaded: Optional[bool] = None
+    threads: Optional[int] = None
+    use_experimental_parser: Optional[bool] = None
+    vars: str = "{}"
+    warn_error: Optional[bool] = None
+
+    # Logging
+    log_format: Optional[LogFormat] = None
+    log_cache_events: Optional[bool] = None
+    record_timing_info: Optional[str] = None
+    debug: Optional[bool] = None
+
+    # Mutually exclusive attributes
+    defer: Optional[bool] = None
+    no_defer: Optional[bool] = dataclasses.field(default=None, repr=False)
+
+    partial_parse: Optional[bool] = None
+    no_partial_parse: Optional[bool] = dataclasses.field(default=None, repr=False)
+
+    use_colors: Optional[bool] = None
+    no_use_colors: Optional[bool] = dataclasses.field(default=None, repr=False)
+
+    static_parser: Optional[bool] = None
+    no_static_parser: Optional[bool] = dataclasses.field(default=None, repr=False)
+
+    version_check: Optional[bool] = None
+    no_version_check: Optional[bool] = dataclasses.field(default=None, repr=False)
+
+    send_anonymous_usage_stats: Optional[bool] = None
+    anonymous_usage_stats: Optional[bool] = dataclasses.field(default=None, repr=False)
+    no_anonymous_usage_stats: Optional[bool] = dataclasses.field(
+        default=None, repr=False
+    )
+
+    write_json: Optional[bool] = None
+    no_write_json: Optional[bool] = dataclasses.field(default=None, repr=False)
 
     def __post_init__(self):
         """Support dictionary args by casting them to str after setting."""
         if isinstance(self.vars, dict):
             self.vars = json.dumps(self.vars)
+        mutually_exclusive_attrs = (
+            "defer",
+            "partial_parse",
+            "use_colors",
+            "static_parser",
+            "version_check",
+            "anonymous_usage_stats",
+            "write_json",
+        )
+
+        for attr in mutually_exclusive_attrs:
+            positive_value = getattr(self, attr, None)
+            negative_value = getattr(self, f"no_{attr}", None)
+
+            if positive_value is None and negative_value is None:
+                continue
+            elif positive_value is not None and negative_value is not None:
+                raise ValueError(f"{attr} and no_{attr} are mutually exclusive")
+            elif positive_value is not None:
+                setattr(self, attr, positive_value)
+            else:
+                setattr(self, attr, not negative_value)
+
+        self.send_anonymous_usage_stats = self.anonymous_usage_stats
 
     @property
     def dbt_task(self) -> BaseTask:
@@ -152,7 +186,7 @@ class BaseConfig:
 
             with open(manifest_path) as f:
                 loaded_manifest = json.load(f)
-                # If I'm taking something from this experience, it's this Mashumaru
+                # If I'm taking something from this experience, it's this Mashumaro
                 # package. I spent a long time trying to build a manifest, when I only
                 # had to call from_dict. Amazing stuff.
                 Manifest.from_dict(loaded_manifest)
@@ -200,9 +234,17 @@ class SelectionConfig(BaseConfig):
     exclude: Optional[list[str]] = None
     select: Optional[list[str]] = None
     selector_name: Optional[list[str]] = None
+    state: Optional[Path] = None
+
     # Kept for compatibility with dbt versions < 0.21
     models: Optional[list[str]] = None
 
+    def __post_init__(self):
+        """Support casting state to Path."""
+        super().__post_init__()
+        if isinstance(self.state, str):
+            self.state = Path(self.state)
+
 
 @dataclass
 class TableMutabilityConfig(SelectionConfig):
@@ -210,21 +252,39 @@ class TableMutabilityConfig(SelectionConfig):
 
     full_refresh: Optional[bool] = None
 
+    def __post_init__(self):
+        """Call superclass __post_init__."""
+        super().__post_init__()
+
 
 @dataclass
 class BuildTaskConfig(TableMutabilityConfig):
     """Dbt build task arguments."""
 
     cls: BaseTask = dataclasses.field(default=BuildTask, init=False)
-    compiled_target: Optional[Union[os.PathLike[str], str]] = None
-    data: Optional[bool] = None
-    indirect_selection: Optional[IndirectSelection] = None
+    singular: Optional[bool] = None
+    indirect_selection: Optional[str] = None
     resource_types: Optional[list[str]] = None
-    schema: Optional[bool] = None
+    generic: Optional[bool] = None
     show: Optional[bool] = None
     store_failures: Optional[bool] = None
     which: str = dataclasses.field(default="build", init=False)
 
+    def __post_init__(self):
+        """Support for type casting arguments."""
+        super().__post_init__()
+        if self.singular is True:
+            try:
+                self.select.append("test_type:singular")
+            except AttributeError:
+                self.select = ["test_type:singular"]
+
+        if self.generic is True:
+            try:
+                self.select.append("test_type:generic")
+            except AttributeError:
+                self.select = ["test_type:generic"]
+
 
 @dataclass
 class CleanTaskConfig(BaseConfig):
@@ -266,8 +326,7 @@ class ListTaskConfig(SelectionConfig):
     """Dbt list task arguments."""
 
     cls: BaseTask = dataclasses.field(default=ListTask, init=False)
-    compiled_target: Optional[Union[os.PathLike[str], str]] = None
-    indirect_selection: Optional[IndirectSelection] = None
+    indirect_selection: Optional[str] = None
     output: Output = Output.SELECTOR
     output_keys: Optional[list[str]] = None
     resource_types: Optional[list[str]] = None
@@ -289,7 +348,6 @@ class RunTaskConfig(TableMutabilityConfig):
     """Dbt run task arguments."""
 
     cls: BaseTask = dataclasses.field(default=RunTask, init=False)
-    compiled_target: Optional[Union[os.PathLike[str], str]] = None
     which: str = dataclasses.field(default="run", init=False)
 
 
@@ -315,7 +373,6 @@ class SeedTaskConfig(TableMutabilityConfig):
 
     cls: BaseTask = dataclasses.field(default=SeedTask, init=False)
     show: Optional[bool] = None
-    compiled_target: Optional[Union[os.PathLike[str], str]] = None
     which: str = dataclasses.field(default="seed", init=False)
 
 
@@ -324,7 +381,6 @@ class SnapshotTaskConfig(SelectionConfig):
     """Dbt snapshot task arguments."""
 
     cls: BaseTask = dataclasses.field(default=SnapshotTask, init=False)
-    compiled_target: Optional[Union[os.PathLike[str], str]] = None
     which: str = dataclasses.field(default="snapshot", init=False)
 
 
@@ -342,12 +398,27 @@ class TestTaskConfig(SelectionConfig):
     """Dbt test task arguments."""
 
     cls: BaseTask = dataclasses.field(default=TestTask, init=False)
-    data: Optional[bool] = None
-    indirect_selection: Optional[IndirectSelection] = None
-    schema: Optional[bool] = None
+    generic: Optional[bool] = None
+    indirect_selection: Optional[str] = None
+    singular: Optional[bool] = None
     store_failures: Optional[bool] = None
     which: str = dataclasses.field(default="test", init=False)
 
+    def __post_init__(self):
+        """Support for type casting arguments."""
+        super().__post_init__()
+        if self.singular is True:
+            try:
+                self.select.append("test_type:singular")
+            except AttributeError:
+                self.select = ["test_type:singular"]
+
+        if self.generic is True:
+            try:
+                self.select.append("test_type:generic")
+            except AttributeError:
+                self.select = ["test_type:generic"]
+
 
 class ConfigFactory(FromStrMixin, Enum):
     """Produce configurations for each dbt task."""
@@ -369,7 +440,6 @@ class ConfigFactory(FromStrMixin, Enum):
     def create_config(self, *args, **kwargs) -> BaseConfig:
         """Instantiate a dbt task config with the given args and kwargs."""
         config = self.value(**kwargs)
-        initialize_config_values(config)
         return config
 
     @property
@@ -393,8 +463,10 @@ class DbtHook(BaseHook):
 
     def initialize_runtime_config(self, config: BaseConfig) -> RuntimeConfig:
         """Set environment flags and return a RuntimeConfig."""
-        flags.reset()
-        flags.set_from_args(config)
+        user_config = read_user_config(flags.PROFILES_DIR)
+        initialize_from_flags()
+        config.cls.set_log_format()
+        flags.set_from_args(config, user_config)
         return RuntimeConfig.from_args(config)
 
     def run_dbt_task(self, config: BaseConfig) -> tuple[bool, Optional[RunResult]]:
